@@ -23,7 +23,7 @@ __docformat__ = "restructuredtext"
 from interfaces import ISchedulerHandler
 
 # import Zope3 packages
-from zope.app.component.metaconfigure import utility
+from zope.component.zcml import utility
 
 # import local packages
 from manager import SchedulerHandler
